@@ -1,4 +1,3 @@
-
 """
     :created: 24.04.2018 by Jens Diemer
     :copyleft: 2018 by the django-tools team, see AUTHORS for more details.
@@ -7,7 +6,7 @@
 
 from django.contrib import messages
 from django.http import HttpResponse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 # https://github.com/jedie/django-tools
 from django_tools.unittest_utils.model_test_code_generator import ModelTestGenerator
@@ -34,7 +33,7 @@ def generate_test_code(modeladmin, request, queryset):
     response = HttpResponse(content, content_type="text/python")
 
     model_label = modeladmin.model._meta.label
-    response['Content-Disposition'] = 'attachment; filename=%s.py' % model_label
+    response['Content-Disposition'] = f'attachment; filename={model_label}.py'
 
     return response
 
