@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     smooth cache backends
     ~~~~~~~~~~~~~~~~~~~~~
@@ -10,16 +8,11 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
 import logging
 import os
 import time
 
-if __name__ == "__main__":
-    # For doctest only
-    os.environ["DJANGO_SETTINGS_MODULE"] = "django.conf.global_settings"
-
 from django.conf import settings
 from django.core.cache.backends.db import DatabaseCache
 from django.core.cache.backends.filebased import FileBasedCache
@@ -27,13 +20,12 @@ from django.core.cache.backends.locmem import LocMemCache
 from django.core.cache.backends.memcached import MemcachedCache, PyLibMCCache
 
 
-
 logger = logging.getLogger("django-tools.SmoothCache")
 if not logger.handlers:
     # ensures we don't get any 'No handlers could be found...' messages
     logger.addHandler(logging.NullHandler())
 
-#if "runserver" in sys.argv or "tests" in sys.argv:
+# if "runserver" in sys.argv or "tests" in sys.argv:
 #    log.logging.basicConfig(format='%(created)f pid:%(process)d %(message)s')
 #    logger.setLevel(log.logging.DEBUG)
 #    logger.addHandler(log.logging.StreamHandler())
@@ -43,14 +35,14 @@ SMOOTH_CACHE_CHANGE_TIME = getattr(settings, "SMOOTH_CACHE_CHANGE_TIME", "DJANGO
 SMOOTH_CACHE_UPDATE_TIMESTAMP = getattr(settings, "SMOOTH_CACHE_UPDATE_TIMESTAMP", 10)
 SMOOTH_CACHE_TIMES = getattr(settings, "SMOOTH_CACHE_TIMES", (
     # load value, max age in sec.
-    (0, 5), #          < 0.1 ->  5sec
-    (0.1, 10), #   0.1 - 0.5 -> 10sec
-    (0.5, 30), #   0.5 - 1.0 -> 30sec
-    (1.0, 60), #   1.0 - 1.5 ->  1Min
-    (1.5, 120), #  1.5 - 2.0 ->  2Min
-    (2.0, 300), #  2.0 - 3.0 ->  5Min
-    (3.0, 900), #  3.0 - 4.0 -> 15Min
-    (4.0, 3600), #     > 4.0 ->  1h
+    (0, 5),  # < 0.1 ->  5sec
+    (0.1, 10),  # 0.1 - 0.5 -> 10sec
+    (0.5, 30),  # 0.5 - 1.0 -> 30sec
+    (1.0, 60),  # 1.0 - 1.5 ->  1Min
+    (1.5, 120),  # 1.5 - 2.0 ->  2Min
+    (2.0, 300),  # 2.0 - 3.0 ->  5Min
+    (3.0, 900),  # 3.0 - 4.0 -> 15Min
+    (4.0, 3600),  # > 4.0 ->  1h
 ))
 
 # Sort from biggest to lowest:
@@ -86,12 +78,12 @@ class SmoothCacheTime(int):
         return i
 
 
-class _SmoothCache(object):
-    __CHANGE_TIME = None # Timestamp of the "last update"
-    __NEXT_SYNC = None # Point in the future to update the __CHANGE_TIME
+class _SmoothCache:
+    __CHANGE_TIME = None  # Timestamp of the "last update"
+    __NEXT_SYNC = None  # Point in the future to update the __CHANGE_TIME
 
     def __init__(self, *args, **kwargs):
-        super(_SmoothCache, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._smooth_clear = None
 
     def __get_change_time(self):
@@ -109,10 +101,10 @@ class _SmoothCache(object):
             change_time = self.get(SMOOTH_CACHE_CHANGE_TIME, raw=True)
             if change_time is None:
                 logger.debug("CHANGE_TIME is None")
-                self.smooth_update() # save change time into cache
+                self.smooth_update()  # save change time into cache
             elif change_time > self.__CHANGE_TIME:
                 self.__CHANGE_TIME = change_time
-                logger.debug("update change time to: %r" % change_time)
+                logger.debug(f"update change time to: {change_time!r}")
 #        else:
 #            logger.debug("Use old CHANGE_TIME %r" % self.__CHANGE_TIME)
 
@@ -127,23 +119,24 @@ class _SmoothCache(object):
         if last_change_time < create_time:
             # Item was added to the cache after the last clear() time.
             logger.debug(
-                "%r not out-dated: added %ssec before clear()" % (
-                    key, (create_time - last_change_time)
-            ))
+                f"{key!r} not out-dated: added {create_time - last_change_time}sec before clear()")
             return False
 
         outdate_age = time.time() - last_change_time
-        load_average = os.getloadavg()[0] # load over last minute
+        load_average = os.getloadavg()[0]  # load over last minute
         max_age = get_max_age(load_average)
         if outdate_age > max_age:
-            logger.debug("Out-dated %r (added %ssec after clear() - age: %s, max age: %s, load: %s)" % (
-                key, (last_change_time - create_time), outdate_age, max_age, load_average
-            ))
+            logger.debug(
+                f"Out-dated {key!r}"
+                f" (added {last_change_time - create_time}sec after clear()"
+                f" - age: {outdate_age}, max age: {max_age}, load: {load_average})"
+            )
             return True
         else:
-            logger.debug("Keep %r by load (out-dated age: %.1fsec, max age: %s, load: %s)" % (
-                key, outdate_age, max_age, load_average
-            ))
+            logger.debug(
+                f"Keep {key!r} by load"
+                f" (out-dated age: {outdate_age:.1f}sec, max age: {max_age}, load: {load_average})"
+            )
             return False
 
     def smooth_update(self):
@@ -153,13 +146,13 @@ class _SmoothCache(object):
         """
         now = int(time.time())
         self.__CHANGE_TIME = now
-        self.set(SMOOTH_CACHE_CHANGE_TIME, now, raw=True) # will be get via __origin_get()
-        logger.debug("Set CHANGE_TIME to %r" % now)
+        self.set(SMOOTH_CACHE_CHANGE_TIME, now, raw=True)  # will be get via __origin_get()
+        logger.debug(f"Set CHANGE_TIME to {now!r}")
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
     def get(self, key, default=None, version=None, raw=False):
-        value = super(_SmoothCache, self).get(key, default, version)
+        value = super().get(key, default, version)
         if raw:
             return value
         if value is None or value is default:
@@ -169,11 +162,11 @@ class _SmoothCache(object):
         try:
             create_time, value = value
             assert isinstance(create_time, SmoothCacheTime), (
-                "create_time is not SmoothCacheTime instance, it's: %s" % type(create_time)
+                f"create_time is not SmoothCacheTime instance, it's: {type(create_time)}"
             )
         except Exception as err:
             # e.g: entry is saved before smooth cache used.
-            logger.error("Can't get 'create_time' from: %s (Maybe %r is a old cache entry?)" % (err, key))
+            logger.error(f"Can't get 'create_time' from: {err} (Maybe {key!r} is a old cache entry?)")
             self.delete(key, version)
             return default
 
@@ -187,30 +180,29 @@ class _SmoothCache(object):
     def set(self, key, value, timeout=None, version=None, raw=False):
         if not raw:
             value = (SmoothCacheTime(), value)
-        super(_SmoothCache, self).set(key, value, timeout, version)
+        super().set(key, value, timeout, version)
 
     def clear(self):
         logger.debug("SmoothCache clear called!")
-        super(_SmoothCache, self).clear()
+        super().clear()
         self.smooth_update()
 
 
 class SmoothFileBasedCache(_SmoothCache, FileBasedCache):
     pass
 
+
 class SmoothDatabaseCache(_SmoothCache, DatabaseCache):
     pass
 
+
 class SmoothLocMemCache(_SmoothCache, LocMemCache):
     pass
 
+
 class SmoothMemcachedCache(_SmoothCache, MemcachedCache):
     pass
 
+
 class SmoothPyLibMCCache(_SmoothCache, PyLibMCCache):
     pass
-
-
-if __name__ == "__main__":
-    import doctest
-    print(doctest.testmod())
