@@ -1,13 +1,11 @@
-# coding:utf-8
-
 """
     SlowerDevServer
     ~~~~~~~~~~~~~~~
-    
+
     Simple slow down the django developer server.
     The middleware insert in every 200 response a time.sleep
-    
-    Put this into your settings:   
+
+    Put this into your settings:
     --------------------------------------------------------------------------
         MIDDLEWARE_CLASSES = (
             ...
@@ -16,7 +14,7 @@
         )
         SLOWER_DEV_SERVER_SLEEP = 0.3 # time.sleep() value (in sec.)
     --------------------------------------------------------------------------
-    
+
     Last commit info:
     ~~~~~~~~~~~~~~~~~
     $LastChangedDate$
@@ -27,14 +25,13 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
 
 import time
 import warnings
 
 from django.conf import settings
 
+
 try:
     from django.utils.deprecation import MiddlewareMixin
 except ImportError:
@@ -44,9 +41,9 @@ except ImportError:
 class SlowerDevServerMiddleware(MiddlewareMixin):
     def __init__(self):
         warnings.warn("Slower developer server used!")
-        
+
     def process_response(self, request, response):
-        if response.status_code == 200: 
-            print("SlowerDevServerMiddleware: Wait for %sSec..." % settings.SLOWER_DEV_SERVER_SLEEP)
+        if response.status_code == 200:
+            print(f"SlowerDevServerMiddleware: Wait for {settings.SLOWER_DEV_SERVER_SLEEP}Sec...")
             time.sleep(settings.SLOWER_DEV_SERVER_SLEEP)
         return response
