@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     Send warnings if a template variable does not exist in the content.
 
@@ -16,15 +14,19 @@
 import warnings
 
 from django import template
+
+
 # from django.utils.encoding import smart_unicode, force_unicode, smart_str
 
 _WARN_ADDED = False
 
 MAX_LEN = 79
 
+
 class InvalidTemplateKey(Warning):
     pass
 
+
 def add_warning():
     global _WARN_ADDED
     if _WARN_ADDED:
@@ -32,9 +34,9 @@ def add_warning():
 
     class WarnVariableDoesNotExist(template.VariableDoesNotExist):
         def __init__(self, *args, **kwargs):
-            super(WarnVariableDoesNotExist, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
 
-            warn_msg = str(self) # get the complete message encoded in UTF-8
+            warn_msg = str(self)  # get the complete message encoded in UTF-8
             if len(warn_msg) > MAX_LEN:
                 warn_msg = warn_msg[:MAX_LEN] + "..."
             warnings.warn(warn_msg, category=InvalidTemplateKey)
