@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     need full validators
     ~~~~~~~~~~~~~~~~~~~~
@@ -8,18 +6,15 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
-
 
 import os
 import re
+from urllib.parse import urlsplit
 
-from django.utils.six.moves import urllib
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.validators import RegexValidator, URLValidator
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 # re from django.utils.translation.trans_real.accept_language_re
@@ -31,7 +26,7 @@ validate_language_code = RegexValidator(
 )
 
 
-class ExistingDirValidator(object):
+class ExistingDirValidator:
     def __init__(self, base_path=settings.MEDIA_ROOT):
         self.base_path = os.path.normpath(os.path.abspath(base_path))
 
@@ -40,7 +35,7 @@ class ExistingDirValidator(object):
 
         if not abs_path.startswith(self.base_path):
             if settings.DEBUG:
-                msg = _("Directory %r is not in base path ('%s')" % (abs_path, self.base_path))
+                msg = _(f"Directory {abs_path!r} is not in base path ('{self.base_path}')")
             else:
                 msg = _("Directory is not in base path!")
             raise ValidationError(msg)
@@ -56,17 +51,24 @@ class ExistingDirValidator(object):
         return abs_path
 
 
-
 class URLValidator2(URLValidator):
     """
     A flexible version of the original django URLValidator ;)
-    
+
     scheme://netloc/path?query#fragment
     """
     regex = re.compile(r'^.+$', re.IGNORECASE)
 
-    def __init__(self, allow_schemes=("http", "https"), allow_all_schemes=False, allow_netloc=True, allow_query=True, allow_fragment=True):
-        super(URLValidator2, self).__init__()
+    def __init__(
+            self,
+            allow_schemes=(
+                "http",
+                "https"),
+            allow_all_schemes=False,
+            allow_netloc=True,
+            allow_query=True,
+            allow_fragment=True):
+        super().__init__()
 
         if __debug__ and (allow_schemes or allow_all_schemes) and not allow_netloc:
             raise AssertionError("Can't allow schemes without netloc!")
@@ -81,10 +83,15 @@ class URLValidator2(URLValidator):
         self.allow_fragment = allow_fragment
 
     def __call__(self, value):
-        scheme, netloc, path, query, fragment = urllib.parse.urlsplit(value)
+        scheme, netloc, path, query, fragment = urlsplit(value)
 
-        if (scheme or netloc) and not self.allow_schemes and not self.allow_all_schemes and not self.allow_netloc:
-            raise ValidationError(_("Please enter a local URL (without protocol/domain)."), code="local")
+        if (scheme or netloc) and \
+                not self.allow_schemes and \
+                not self.allow_all_schemes and \
+                not self.allow_netloc:
+            raise ValidationError(
+                _("Please enter a local URL (without protocol/domain)."), code="local"
+            )
 
         if scheme:
             if not self.allow_all_schemes and scheme not in self.allow_schemes:
@@ -98,12 +105,3 @@ class URLValidator2(URLValidator):
 
         if fragment and not self.allow_fragment:
             raise ValidationError(_('Enter a valid URL without a fragment.'), code='fragment')
-
-
-
-if __name__ == "__main__":
-    import doctest
-    print(doctest.testmod(
-#        verbose=True
-        verbose=False
-    ))
